library ieee;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity configcpld is
   port(
      RESET_N        	: in std_logic;  -- PU
      FPGA_RESET_N   	: in std_logic;  -- PU
      PROG_B     	: out std_logic; -- PU

      CM0        	: in std_logic;  -- PU
      CM1		: in std_logic;  -- PU

      M0		: out std_logic;  
      M1		: out std_logic;  
      M2		: out std_logic;  

      D0		: in std_logic;  
      D1		: in std_logic;  
      MOSI_D0		: out std_logic;  
      MISO_D1		: out std_logic;  
      
      CTL5  		: in std_logic;
      CCLK  		: out std_logic;

      FLASH_CS		: in std_logic;  
      FLASH_RH_N	: in std_logic;
      FLASH_WP_N	: in std_logic
   );
end configcpld;

-- CM1,CM0    description
-- 0,0        Flash config
-- 1,0        HS config
-- 0,1        LS config
-- 1,1        JTAG only
architecture RTL of configcpld is

--signal declaration
begin
    PROG_B <= RESET_N and FPGA_RESET_N;
--    PROG_B <= '1';
    
    M2 <= '1' when ( (CM0 or CM1) = '1' ) else '0';
    M1 <= '0' when ( CM0 = CM1 ) else '1';
    M0 <= '1' when ( CM0 = CM1 ) else '0';
--    M2 <= '0' when ( (CM0 or CM1) = '0' ) else '1';
--    M1 <= '0' when ( (CM0 or CM1) = '0' ) else '1';
--    M0 <= '1' when ( (CM0 or CM1) = '0' ) else '0';

    MOSI_D0 <= 'Z' when ( CM0 = CM1 ) else D0;
    MISO_D1 <= 'Z' when ( CM0 = CM1 ) else D1;

    CCLK <= CTL5 when ( (CM0 = '0') and (CM1 = '1')) else 'Z';

end RTL;

